==> netmrg_0.18.2.orig.tar.gz: netmrg-0.18.2/www/webfiles/images/default/imagespec.php <==
<?php
/**
* imagespec.php
*
* specfile for images
*/

$imagepackname = "default";
$GLOBALS["netmrg"]["imagedir"] = "{$GLOBALS['netmrg']['webroot']}/images/$imagepackname";
$GLOBALS["netmrg"]["imagespec"] = array(
	"applytemplate" => "applytemplate.png",
	"edit" => "edit.png",
	"logo" => "netmrg-logo-small.png",
	"delete" => "delete.png",
	"disk" => "disk.png",
	"duplicate" => "duplicate.png",
	"arrow-up" => "arrow-up.png",
	"arrow-right" => "arrow-right.png",
	"arrow-down" => "arrow-down.png",
	"arrow-left" => "arrow-left.png",
	"arrow-up-disabled" => "arrow-up-disabled.png",
	"arrow-right-disabled" => "arrow-right-disabled.png",
	"arrow-down-disabled" => "arrow-down-disabled.png",
	"arrow-left-disabled" => "arrow-left-disabled.png",
	"parameters" => "parameters.png",
	"view" => "view.png",
	"recachedisk" => "recachedisk.png",
	"viewdisk" => "viewdisk.png",
	"recacheinterface" => "recacheinterface.png",
	"viewinterface" => "viewinterface.png",
	"viewgraph-on" => "viewgraph-on.png",
	"viewgraph-off" => "viewgraph-off.png",
	"slideshow" => "slideshow.png",
	"status-good-trig"       => "status-good-trig.png",
	"status-good-untrig"     => "status-good-untrig.png",
	"status-warning-trig"    => "status-warning-trig.png",
	"status-warning-untrig"  => "status-warning-untrig.png",
	"status-critical-trig"   => "status-critical-trig.png",
	"status-critical-untrig" => "status-critical-untrig.png",
	"status-unknown-trig"    => "status-unknown-trig.png",
	"status-unknown-untrig"  => "status-unknown-untrig.png"
);
?>

==> netmrg_0.20.orig.tar.gz: netmrg-0.20/www/webfiles/images/default/imagespec.php <==
<?php
/**
* imagespec.php
*
* specfile for images
*/

$imagepackname = "default";
$GLOBALS["netmrg"]["imagedir"] = "{$GLOBALS['netmrg']['webroot']}/images/$imagepackname";
$GLOBALS["netmrg"]["imagespec"] = array(
	"applytemplate" => "applytemplate.png",
	"edit" => "edit.png",
	"logo" => "netmrg-logo-small.png",
	"delete" => "delete.png",
	"disk" => "disk.png",
	"duplicate" => "duplicate.png",
	"arrow-up" => "arrow-up.png",
	"arrow-right" => "arrow-right.png",
	"arrow-down" => "arrow-down.png",
	"arrow-left" => "arrow-left.png",
	"arrow-up-disabled" => "arrow-up-disabled.png",
	"arrow-right-disabled" => "arrow-right-disabled.png",
	"arrow-down-disabled" => "arrow-down-disabled.png",
	"arrow-left-disabled" => "arrow-left-disabled.png",
	"arrow_limit-up" => "arrow_limit-up.png",
	"arrow_limit-right" => "arrow_limit-right.png",
	"arrow_limit-down" => "arrow_limit-down.png",
	"arrow_limit-left" => "arrow_limit-left.png",
	"arrow_limit-up-disabled" => "arrow_limit-up-disabled.png",
	"arrow_limit-right-disabled" => "arrow_limit-right-disabled.png",
	"arrow_limit-down-disabled" => "arrow_limit-down-disabled.png",
	"arrow_limit-left-disabled" => "arrow_limit-left-disabled.png",
	"parameters" => "parameters.png",
	"view" => "view.png",
	"recachedisk" => "recachedisk.png",
	"recacheproperties" => "recacheproperties.png",
	"viewdisk" => "viewdisk.png",
	"recacheinterface" => "recacheinterface.png",
	"viewinterface" => "viewinterface.png",
	"viewgraph-on" => "viewgraph-on.png",
	"viewgraph-off" => "viewgraph-off.png",
	"slideshow" => "slideshow.png",
	"status-good-trig"       => "status-good-trig.png",
	"status-good-untrig"     => "status-good-untrig.png",
	"status-warning-trig"    => "status-warning-trig.png",
	"status-warning-untrig"  => "status-warning-untrig.png",
	"status-critical-trig"   => "status-critical-trig.png",
	"status-critical-untrig" => "status-critical-untrig.png",
	"status-unknown-trig"    => "status-unknown-trig.png",
	"status-unknown-untrig"  => "status-unknown-untrig.png"
);
?>
